==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/Wizard.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef WIZARD_H
#define WIZARD_H

#include <wx/dialog.h>                  // Needed for wxDialog
#include <wx/listctrl.h>                // Needed for wxListCtrl

#include "Preferences.h"                // Needed for CPreferences

class Wizard : public wxDialog
{
  //DECLARE_DYNAMIC(Wizard)

public:
	Wizard(wxWindow* pParent = NULL);   // standard constructor
	virtual ~Wizard();
	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }
	virtual BOOL OnInitDialog();

	int m_iOS;
	int m_iTotalDownload;

// Dialog Data
	enum { IDD };
protected:
	CPreferences* app_prefs;
protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//DECLARE_MESSAGE_MAP()
	DECLARE_EVENT_TABLE()
public:
	void OnBnClickedApply(wxEvent& evt);
	void OnBnClickedCancel(wxEvent& evt);
	void OnBnClickedWizRadioOsNtxp(wxEvent& evt);
	void OnBnClickedWizRadioUs98me(wxEvent& evt);
	void OnBnClickedWizLowdownloadRadio(wxEvent& evt);
	void OnBnClickedWizMediumdownloadRadio(wxEvent& evt);
	void OnBnClickedWizHighdownloadRadio(wxEvent& evt);
	void OnBnClickedWizResetButton(wxEvent& evt);
protected:
	//CListCtrl m_provider;
	wxListCtrl* m_provider;
private:
	void SetCustomItemsActivation();
public:
	//afx_msg void OnNMClickProviders(NMHDR *pNMHDR, LRESULT *pResult);
	void OnNMClickProviders(wxListEvent& evt);

};

#endif

==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/Wizard.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef WIZARD_H
#define WIZARD_H

#include <wx/dialog.h>                      // Needed for wxDialog

class CPreferences;
class wxListCtrl;
class wxListEvent;

class Wizard: public wxDialog
{

public:
	Wizard(wxWindow* pParent = NULL);   // standard constructor
	virtual ~Wizard();
	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }
	virtual bool OnInitDialog();

	int m_iOS;
	int m_iTotalDownload;

// Dialog Data
	enum { IDD };
protected:
	CPreferences* app_prefs;
protected:
	DECLARE_EVENT_TABLE()
public:
	void OnBnClickedApply(wxCommandEvent & evt);
	void OnBnClickedCancel(wxCommandEvent & evt);
	void OnBnClickedWizRadioOsNtxp(wxCommandEvent & evt);
	void OnBnClickedWizRadioUs98me(wxCommandEvent & evt);
	void OnBnClickedWizLowdownloadRadio(wxCommandEvent & evt);
	void OnBnClickedWizMediumdownloadRadio(wxCommandEvent & evt);
	void OnBnClickedWizHighdownloadRadio(wxCommandEvent & evt);
	void OnBnClickedWizResetButton(wxCommandEvent & evt);
protected:
	wxListCtrl* m_provider;
private:
	void SetCustomItemsActivation();
public:
	void OnNMClickProviders(wxListEvent& evt);

};

#endif
